#' @keywords internal
"_PACKAGE"

## usethis namespace: start
## usethis namespace: end
NULL

utils::globalVariables(c("Country",
                         "Country or area",
                         "Region",
                         "average_year",
                         "column",
                         "cor",
                         "column",
                         "public_cor",
                         "private_cor",
                         "floored_year",
                         "index_year",
                         "median",
                         "mutate",
                         "index_country",
                         "index_method",
                         "index_sector",
                         "quantile",
                         "Method",
                         "Sector",
                         "median_p",
                         "lower_80",
                         "upper_80",
                         "lower_95",
                         "upper_95",
                         "params",
                         "mu_pred",
                         "Super_region",
                         "index_superregion",
                         "sector_category",
                         "proportion",
                         "prop.trans",
                         "n",
                         "proportion_Commercial_medical",
                         "proportion_Public",
                         "proportion_Other",
                         "Commercial_medical",
                         "Other",
                         "Public",
                         "logit.Public.Var",
                         "logit.CM.Var",
                         "logit.Public.SE",
                         "logit.CM.SE",
                         "logit.Public",
                         "logit.CM",
                         "count_NA",
                         "SE.proportion",
                         "SE.proportion_Commercial_medical",
                         "SE.proportion_Other",
                         "SE.proportion_Public",
                         "Public.SE",
                         "Commercial_medical.SE",
                         "Other.SE",
                         "se.Public",
                         "se.Commercial_medical",
                         "se.Other",
                         "Other_n",
                         "Public_n",
                         "Commercial_medical_n",
                         "row_id",
                         "max.Other.SE",
                         "max.Public.SE",
                         "max.Commercial_medical.SE",
                         "sector_categories",
                         "n_Commercial_medical",
                         "n_Public",
                         "n_Other",
                         "check_total",
                         "count_SE.NA",
                         "floored_year",
                         "P",
                         "prop_max",
                         "prop_min",
                         "index_subnat",
                         "mod",
                         "sample_id",
                         "p_samp"))
